__author__ = 'Joe Linn'

import requests


class Pyflare(object):
    class APIError(Exception):
        def __init__(self, msg, code=None):
            self.msg = msg
            self.code = code
            Exception.__init__(self, msg, code)

        def __str__(self):
            return '{0} - {1}'.format(self.code, self.msg) if self.code is not None else self.msg

    CLOUDFLARE_URL = 'https://www.cloudflare.com/api_json.html'

    def __init__(self, email, token):
        """
        Instantiate a Pyflare client object
        :param email: The email address associated with your Cloudflare account
        :type email: str
        :param token: The API key associated with your Cloudflare account
        :type token: str
        """
        self._email = email
        self._token = token

    def stats(self, zone, interval):
        """
        Retrive the current stats and settings for a particular website.
        :param zone:  The domain for which statistics are being retrieved.
        :type zone: str
        :param interval: The time interval for the statistics denoted by the following values:
            20 = Past 30 days
            30 = Past 7 days
            40 = Past day

            The values are for Pro accounts
            100 = 24 hours ago
            110 = 12 hours ago
            120 = 6 hours ago
        :type interval: int
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'stats',
            'z': zone,
            'interval': interval
        })

    def zone_load_multi(self):
        """
        Lists all domains in a CloudFlare account, along with other data.
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'zone_load_multi'
        })

    def rec_load_all(self, zone):
        """
        Lists all DNS records for the given domain
        :param zone: the domain for which records are being retrieved
        :type zone: str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'rec_load_all',
            'z': zone
        })

    def zone_check(self, zones):
        """
        Checks for active zones and returns their corresponding zids
        :param zones: List of zones
        :type zones: list of str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'zone_check',
            'zones': ','.join(zones)
        })

    def zone_ips(self, zone, hours=24, ip_class=None, geo=False):
        """
        Retrieve IP addresses of recent visitors
        :param zone: the target domain
        :type zone: str
        :param hours: Past number of hours to query. Defaults to 24, maximum is 48.
        :type hours: int
        :param ip_class: Optional. Restrict the result set to a given class as given by:
            "r" -- regular
            "s" -- crawler
            "t" -- threat
        :type ip_class: str
        :param geo: Optional. Set to True to add longitude and latitude information to response
        :type geo: bool
        :return:
        :rtype: dict
        """
        params = {
            'a': 'zone_ips',
            'z': zone,
            'hours': hours,
            'class': ip_class,
        }
        if geo:
            params['geo'] = geo
        return self._request(params)

    def ip_lkup(self, ip):
        """
        Find the current threat score for a given IP. Note that scores are on a logarithmic scale, where a higher score
        indicates a higher threat.
        :param ip: the target IP
        :type ip: str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'ip_lkup',
            'ip': ip
        })

    def zone_settings(self, zone):
        """
        Retrieves all current settings for a given domain.
        :param zone: the target domain
        :type zone: str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'zone_settings',
            'z': zone
        })

    def sec_lvl(self, zone, level):
        """
        Set the security level for the given zone
        :param zone: domain name
        :type zone: str
        :param level: security level:
            "help" -- I'm under attack!
            "high" -- High
            "med" -- Medium
            "low" -- Low
            "eoff" -- Essentially Off
        :type level: str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'sec_lvl',
            'z': zone,
            'v': level
        })

    def cache_lvl(self, zone, level):
        """
        Set the caching level for the given zone
        :param zone: domain name
        :type zone: str
        :param level: cache level:
            "agg" -- Aggressive
            "basic" -- Basic
        :type level: str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'cache_lvl',
            'z': zone,
            'v': level
        })

    def devmode(self, zone, enabled):
        """
        This function allows you to toggle Development Mode on or off for a particular domain.
        When Development Mode is on the cache is bypassed. Development mode remains on for 3 hours or
        until when it is toggled back off.
        :param zone: domain name
        :type zone: str
        :param enabled: True to turn dev mode on, False to turn dev mode off.
        :type enabled: bool
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'devmode',
            'z': zone,
            'v': int(enabled)
        })

    def fpurge_ts(self, zone):
        """
        This function will purge CloudFlare of any cached files. It may take up to 48 hours for the cache to
        rebuild and optimum performance to be achieved so this function should be used sparingly.
        :param zone: domain name
        :type zone: str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'fpurge_ts',
            'z': zone,
            'v': 1      # Value can only be "1."
        })

    def zone_file_purge(self, zone, url):
        """
        This function will purge a single file from CloudFlare's cache.
        :param zone: domain name
        :type zone: str
        :param url: The full URL of the file that needs to be purged from Cloudflare's cache. Keep in mind
            that if an HTTP and an HTTPS version of the file exists, then both versions will need to be purged
            independently.
        :type url: str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'zone_file_purge',
            'z': zone,
            'url': url
        })

    def zone_grab(self, zone_id):
        """
        Update the snapshot of site for CloudFlare's challenge page
        :param zone_id: ID of zone, found in zone_check
        :type zone_id: int
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'zone_grab',
            'zid': zone_id
        })

    def wl(self, ip):
        """
        Whitelist an ip address
        :param ip: The IP address you want to whitelist
        :type ip: str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'wl',
            'key': ip
        })

    def ban(self, ip):
        """
        Blacklist an ip address
        :param ip: The IP address you want to ban
        :type ip: str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'ban',
            'key': ip
        })

    def nul(self, ip):
        """
        Remove an IP address from the whitelist or blacklist
        :param ip: The IP address to remove
        :type ip: str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'nul',
            'key': ip
        })

    def ipv46(self, zone, enable):
        """
        Toggles IPv6 support
        :param zone: domain name
        :type zone: str
        :param enable: True to enable, False to disable.
        :type enable: bool
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'ipv46',
            'z': zone,
            'v': int(enable)
        })

    def async(self, zone, setting):
        """
        Changes Rocket Loader setting
        :param zone: domain name
        :type zone: str
        :param setting: [0 = off, a = automatic, m = manual]
        :type setting: int or str
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'async',
            'z': zone,
            'v': setting
        })

    def minify(self, zone, setting):
        """
        Changes minification settings
        :param zone: domain name
        :type zone: str
        :param setting:
            0 = off
            1 = JavaScript only
            2 = CSS only
            3 = JavaScript and CSS
            4 = HTML only
            5 = JavaScript and HTML
            6 = CSS and HTML
            7 = CSS, JavaScript, and HTML
        :type setting: int
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'minify',
            'z': zone,
            'v': setting
        })

    def mirage2(self, zone, enable):
        """
        Toggles mirage2 support
        :param zone: domain name
        :type zone: str
        :param enable: True to enable, False to disable.
        :type enable: bool
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'mirage2',
            'z': zone,
            'v': int(enable)
        })

    def rec_new(self, zone, record_type, name, content, ttl=1, priority=None, service=None, service_name=None,
                protocol=None, weight=None, port=None, target=None):
        """
        Create a DNS record for the given zone
        :param zone: domain name
        :type zone: str
        :param record_type: Type of DNS record. Valid values are [A/CNAME/MX/TXT/SPF/AAAA/NS/SRV/LOC]
        :type record_type: str
        :param name: name of the DNS record
        :type name: str
        :param content: content of the DNS record
        :type content: str
        :param ttl: TTL of the DNS record in seconds. 1 = Automatic, otherwise, value must in between 120 and
            4,294,967,295 seconds.
        :type ttl: int
        :param priority: [applies to MX/SRV] MX record priority.
        :type priority: int
        :param service: Service for SRV record
        :type service: str
        :param service_name: Service Name for SRV record
        :type service_name: str
        :param protocol: Protocol for SRV record. Values are [_tcp/_udp/_tls].
        :type protocol: str
        :param weight: Weight for SRV record.
        :type weight: int
        :param port: Port for SRV record
        :type port: int
        :param target: Target for SRV record
        :type target: str
        :return:
        :rtype: dict
        """
        params = {
            'a': 'rec_new',
            'z': zone,
            'type': record_type,
            'name': name,
            'content': content,
            'ttl': ttl
        }
        if priority is not None:
            params['prio'] = priority
        if service is not None:
            params['service'] = service
        if service_name is not None:
            params['srvname'] = service_name
        if protocol is not None:
            params['protocol'] = protocol
        if weight is not None:
            params['weight'] = weight
        if port is not None:
            params['port'] = port
        if target is not None:
            params['target'] = target
        return self._request(params)

    def rec_edit(self, zone, record_type, record_id, name, content, ttl=1, service_mode=None, priority=None,
                 service=None, service_name=None, protocol=None, weight=None, port=None, target=None):
        """
        Edit a DNS record for the given zone.
        :param zone: domain name
        :type zone: str
        :param record_type: Type of DNS record. Valid values are [A/CNAME/MX/TXT/SPF/AAAA/NS/SRV/LOC]
        :type record_type: str
        :param record_id: DNS Record ID. Available by using the rec_load_all call.
        :type record_id: int
        :param name: Name of the DNS record
        :type name: str
        :param content: The content of the DNS record, will depend on the the type of record being added
        :type content: str
        :param ttl: TTL of record in seconds. 1 = Automatic, otherwise, value must in between 120 and 4,294,967,295
            seconds.
        :type ttl: int
        :param service_mode: [applies to A/AAAA/CNAME] Status of CloudFlare Proxy, 1 = orange cloud, 0 = grey cloud.
        :type service_mode: int
        :param priority: [applies to MX/SRV] MX record priority.
        :type priority: int
        :param service: Service for SRV record
        :type service: str
        :param service_name: Service Name for SRV record
        :type service_name: str
        :param protocol: Protocol for SRV record. Values are [_tcp/_udp/_tls].
        :type protocol: str
        :param weight: Weight for SRV record.
        :type weight: int
        :param port: Port for SRV record
        :type port: int
        :param target: Target for SRV record
        :type target: str
        :return:
        :rtype: dict
        """
        params = {
            'a': 'rec_edit',
            'z': zone,
            'type': record_type,
            'id': record_id,
            'name': name,
            'content': content,
            'ttl': ttl
        }
        if service_mode is not None:
            params['service_mode'] = service_mode
        if priority is not None:
            params['prio'] = priority
        if service is not None:
            params['service'] = service
        if service_name is not None:
            params['srvname'] = service_name
        if protocol is not None:
            params['protocol'] = protocol
        if weight is not None:
            params['weight'] = weight
        if port is not None:
            params['port'] = port
        if target is not None:
            params['target'] = target
        return self._request(params)

    def rec_delete(self, zone, record_id):
        """
        Delete a record for the given domain.
        :param zone: domain name
        :type zone: str
        :param record_id: DNS Record ID. Available by using the rec_load_all call.
        :type record_id: int
        :return:
        :rtype: dict
        """
        return self._request({
            'a': 'rec_delete',
            'z': zone,
            'id': record_id
        })

    def _request(self, data):
        """

        :param data: Request body to be sent to Cloudflare
        :type data: dict
        :return: Response from Cloudflare
        :rtype: dict
        """
        data['tkn'] = self._token
        data['email'] = self._email
        response = requests.post(self.CLOUDFLARE_URL, data=data).json()
        if response['result'] == 'error':
            raise self.APIError(response['msg'], response.get('err_code'))
        return response



__author__ = 'Joe Linn'

import unittest
from pyflare import Pyflare
from mock_responses import mock_response


class PyflareTest(unittest.TestCase):
    def setUp(self):
        self.pyflare = Pyflare('address@example.com', 'your_api_key')

    @mock_response
    def test_stats(self):
        response = self.pyflare.stats('example.com', 40)
        self.assertIsInstance(response['response']['result']['timeZero'], int)

    @mock_response
    def test_zone_load_multi(self):
        response = self.pyflare.zone_load_multi()
        self.assertIsInstance(response['response']['zones']['count'], int)

    @mock_response
    def test_rec_load_all(self):
        response = self.pyflare.rec_load_all('example.com')
        self.assertIsInstance(response['response']['recs']['count'], int)

    @mock_response
    def test_zone_check(self):
        response = self.pyflare.zone_check(['example.com'])
        for zone, zid in response['response']['zones'].iteritems():
            self.assertIsInstance(zid, int)

    @mock_response
    def test_zone_ips(self):
        response = self.pyflare.zone_ips('example.com')
        self.assertIsInstance(response['response']['ips'], list)

    @mock_response
    def test_ip_lkup(self):
        ip = '0.0.0.0'
        response = self.pyflare.ip_lkup(ip)
        self.assertIn(ip, response['response'])

    @mock_response
    def test_zone_settings(self):
        response = self.pyflare.zone_settings('example.com')
        self.assertIsInstance(response['response']['result']['objs'], list)

    @mock_response
    def test_sec_lvl(self):
        response = self.pyflare.sec_lvl('example.com', 'med')
        self.assertEqual(response['result'], 'success')

    @mock_response
    def test_cache_lvl(self):
        response = self.pyflare.cache_lvl('example.com', 'agg')
        self.assertEqual(response['result'], 'success')

    @mock_response
    def test_devmode(self):
        response = self.pyflare.devmode('example.com', False)
        self.assertIn('zone_id', response['response']['zone']['obj'])

    @mock_response
    def test_fpurge_ts(self):
        response = self.pyflare.fpurge_ts('example.com')
        self.assertIsInstance(response['response']['fpurge_ts'], int)

    @mock_response
    def test_zone_file_purge(self):
        response = self.pyflare.zone_file_purge('example.com', 'https://example.com/image.jpg')
        self.assertIn('url', response['response'])
        self.assertEqual(response['result'], 'success')

    @mock_response
    def test_zone_grab(self):
        response = self.pyflare.zone_grab(9001)
        self.assertEqual(response['result'], 'success')

    @mock_response
    def test_wl(self):
        response = self.pyflare.wl('0.0.0.0')
        self.assertEqual(response['result'], 'success')
        self.assertEqual(response['response']['result']['action'], 'WL')

    @mock_response
    def test_ban(self):
        response = self.pyflare.ban('0.0.0.0')
        self.assertEqual(response['result'], 'success')
        self.assertEqual(response['response']['result']['action'], 'BAN')

    @mock_response
    def test_nul(self):
        response = self.pyflare.nul('0.0.0.0')
        self.assertEqual(response['result'], 'success')
        self.assertEqual(response['response']['result']['action'], 'NUL')

    @mock_response
    def test_ipv46(self):
        response = self.pyflare.ipv46('example.com', False)
        self.assertEqual(response['result'], 'success')

    @mock_response
    def test_async(self):
        response = self.pyflare.async('example.com', 0)
        self.assertEqual(response['result'], 'success')

    @mock_response
    def test_minify(self):
        response = self.pyflare.minify('example.com', 0)
        self.assertEqual(response['result'], 'success')

    @mock_response
    def test_mirage2(self):
        response = self.pyflare.mirage2('example.com', False)
        self.assertEqual(response['result'], 'success')

    @mock_response
    def test_rec_new(self):
        response = self.pyflare.rec_new('example.com', 'A', 'sub', '1.2.3.4')
        self.assertIn('rec_id', response['response']['rec']['obj'])

    @mock_response
    def test_rec_edit(self):
        response = self.pyflare.rec_edit('example.com', 'A', 9001, 'sub', '1.2.3.4')
        self.assertIn('rec_id', response['response']['rec']['obj'])

    @mock_response
    def test_rec_delete(self):
        response = self.pyflare.rec_delete('example.com', 9001)
        self.assertEqual(response['result'], 'success')

if __name__ == '__main__':
    unittest.main()



__author__ = 'Joe Linn'

import functools
import json
import httpretty
from pyflare import Pyflare


def mock_response(test):
    @functools.wraps(test)      # ensure that the test_* function names are retained so that tests are discovered by nose
    @httpretty.activate
    def wrapper(*args, **kw):
        name = test.__name__.replace('test_', '')
        httpretty.httpretty.register_uri(httpretty.httpretty.POST, Pyflare.CLOUDFLARE_URL,
                                         body=responses[name], content_type='application/json')
        return test(*args, **kw)
    return wrapper

responses = {
    'stats': json.dumps({"response": {"result": {"timeZero": 1333051372000,"timeEnd": 1335643372000,"count": 1,"has_more": False,"objs": [{"cachedServerTime": 1335816172000,"cachedExpryTime": 1335859372000,"trafficBreakdown": {"pageviews": {"regular": 2640,"threat": 27,"crawler": 4},"uniques": {"regular": 223,"threat": 16,"crawler": 4}},"bandwidthServed": {"cloudflare": 78278.706054688,"user": 58909.374023438},"requestsServed": {"cloudflare": 4173,"user": 3697},"pro_zone": False,"pageLoadTime": None,"currentServerTime": 1335824051000,"interval": 20,"zoneCDate": 1307574643000,"userSecuritySetting": "Medium","dev_mode": 0,"ipv46": 5,"ob": 0,"cache_lvl": "agg"}]}},"result": "success","msg": None}),
    'zone_load_multi': json.dumps({"request": {"act": "zone_load_multi","a": "zone_load_multi","email": "sample@example.com","tkn": "8afbe6dea02407989af4dd4c97bb6e25"},"response": {"zones": {"has_more": False,"count": 3,"objs": [{"zone_id": "42","user_id": "1","zone_name": "exampledomain1.com","display_name": "exampledomain1.com","zone_status": "V","zone_mode": "1","host_id": "415","zone_type": "P","host_pubname": "WebHost","host_website": "http://WEBSITEOFHOST.com","vtxt": None,"fqdns": None,"step": "4","zone_status_class": "statusactive","zone_status_desc": "CloudFlare powered, this website will be accelerated and protected (<a class=\"modallinkfaq muted\" href=\"#\" onClick=\"cloudFlare.faq('en_US', ['CompleteActive']);return False;\">info</a>)","ns_vanity_map": [ ],"orig_registrar": None,"orig_dnshost": None,"orig_ns_names": None,"props": {"dns_cname": 0,"dns_partner": 1,"dns_anon_partner": 0,"pro": 0,"expired_pro": 0,"pro_sub": 0,"ssl": 0,"expired_ssl": 0,"expired_rs_pro": 0,"reseller_pro": 0,"force_interal": 0,"ssl_needed": 0,"alexa_rank": 0},"confirm_code": {"zone_deactivate": "f91eb75acb516aa95dabf5fa2b7305ec","zone_dev_mode1": "84fae8e497487d5dea45a39f00054488"},"allow": ["analytics","threat_control","cf_apps","dns_editor","cf_settings","page_rules","zone_deactivate","zone_dev_mode1"]},{"zone_id": "43","user_id": "1","zone_name": "exampledomain2.net","display_name": "exampledomain2.net","zone_status": "V","zone_mode": "0","host_id": None,"zone_type": "F","host_pubname": None,"host_website": None,"vtxt": None,"fqdns": ["norm.ns.cloudflare.com","pat.ns.cloudflare.com"],"step": "4","zone_status_class": "statusdeactivated","zone_status_desc": "Deactivated: Web traffic to this website will no longer pass through the CloudFlare system. We will continue to resolve your DNS. However, you will not receive the benefits of CloudFlare. You may <a href=\"/mywebsites.html?act=zone_reactivate&z=exampledomain2.net\">reactivate</a> CloudFlare for this website at any time. (<a class=\"modallinkfaq muted\" href=\"javascript:void(0);\" onClick=\"cloudFlare.faq('en_US', ['DeactivateInProgress']);return False;\">help</a>)","ns_vanity_map": [ ],"orig_registrar": "A Registrar!","orig_dnshost": None,"orig_ns_names": "{NS1.OLDNAMESERVER.COM,NS2.OLDNAMESERVER.COM}","props": {"dns_cname": 0,"dns_partner": 0,"dns_anon_partner": 0,"pro": 0,"expired_pro": 0,"pro_sub": 0,"ssl": 0,"expired_ssl": 0,"expired_rs_pro": 0,"reseller_pro": 0,"force_interal": 0,"ssl_needed": 0,"alexa_rank": 0},"confirm_code": {"zone_delete": "79fece02a0b6db49ba25d78490142ba2"},"allow": ["zone_reactivate","analytics","zone_delete","dns_editor","cf_settings","page_rules"]},{"zone_id": "44","user_id": "1","zone_name": "exampledomain3.org","display_name": "exampledomain3.org","zone_status": "V","zone_mode": "1","host_id": "115","zone_type": "P","host_pubname": "Some Host!","host_website": "WEBSITEOFHOST.org","vtxt": None,"fqdns": None,"step": "4","zone_status_class": "statusactive","zone_status_desc": "CloudFlare powered, this website will be accelerated and protected (<a class=\"modallinkfaq muted\" href=\"#\" onClick=\"cloudFlare.faq('en_US', ['CompleteActive']);return False;\">info</a>)","ns_vanity_map": [ ],"orig_registrar": None,"orig_dnshost": None,"orig_ns_names": None,"props": {"dns_cname": 0,"dns_partner": 1,"dns_anon_partner": 0,"pro": 0,"expired_pro": 0,"pro_sub": 0,"ssl": 0,"expired_ssl": 0,"expired_rs_pro": 0,"reseller_pro": 0,"force_interal": 0,"ssl_needed": 0,"alexa_rank": 0},"confirm_code": {"zone_deactivate": "c85831462b7bf79d69ad82aba1fa02ce","zone_dev_mode1": "fc6cacf3b4ef5bbdb9c0099a9762ae94"},"allow": ["analytics","threat_control","cf_apps","dns_editor","cf_settings","page_rules","zone_deactivate","zone_dev_mode1"]}]}},"result": "success","msg": None}),
    'rec_load_all': json.dumps({"request": {"act": "rec_load_all","a": "rec_load_all","email": "sample@example.com","tkn": "8afbe6dea02407989af4dd4c97bb6e25","z": "example.com"},"response": {"recs": {"has_more": False,"count": 7,"objs": [{"rec_id": "16606009","rec_tag": "7f8e77bac02ba65d34e20c4b994a202c","zone_name": "example.com","name": "direct.example.com","display_name": "direct","type": "A","prio": None,"content": "[server IP]","display_content": "[server IP]","ttl": "1","ttl_ceil": 86400,"ssl_id": None,"ssl_status": None,"ssl_expires_on": None,"auto_ttl": 1,"service_mode": "0","props": {"proxiable": 1,"cloud_on": 0,"cf_open": 1,"ssl": 0,"expired_ssl": 0,"expiring_ssl": 0,"pending_ssl": 0}},{"rec_id": "16606003","rec_tag": "d5315634e9f5660d3670e62fa176e5de","zone_name": "example.com","name": "home.example.com","display_name": "home","type": "A","prio": None,"content": "[server IP]","display_content": "[server IP]","ttl": "1","ttl_ceil": 86400,"ssl_id": None,"ssl_status": None,"ssl_expires_on": None,"auto_ttl": 1,"service_mode": "0","props": {"proxiable": 1,"cloud_on": 0,"cf_open": 1,"ssl": 0,"expired_ssl": 0,"expiring_ssl": 0,"pending_ssl": 0}},{"rec_id": "16606000","rec_tag": "23b26c051884e94e18711742942760b1","zone_name": "example.com","name": "example.com","display_name": "example.com","type": "A","prio": None,"content": "[server IP]","display_content": "[server IP]","ttl": "1","ttl_ceil": 86400,"ssl_id": None,"ssl_status": None,"ssl_expires_on": None,"auto_ttl": 1,"service_mode": "1","props": {"proxiable": 1,"cloud_on": 1,"cf_open": 1,"ssl": 0,"expired_ssl": 0,"expiring_ssl": 0,"pending_ssl": 0}},{"rec_id": "18136402","rec_tag": "3bcef45cdf5b7638b13cfb89f1b6e716","zone_name": "example.com","name": "test.example.com","display_name": "test","type": "A","prio": None,"content": "[server IP]","display_content": "[server IP]","ttl": "1","ttl_ceil": 86400,"ssl_id": None,"ssl_status": None,"ssl_expires_on": None,"auto_ttl": 1,"service_mode": "0","props": {"proxiable": 1,"cloud_on": 0,"cf_open": 1,"ssl": 0,"expired_ssl": 0,"expiring_ssl": 0,"pending_ssl": 0}},{"rec_id": "16606018","rec_tag": "c0b453b2d94213a7930d342114cbda86","zone_name": "example.com","name": "www.example.com","display_name": "www","type": "CNAME","prio": None,"content": "example.com","display_content": "example.com","ttl": "1","ttl_ceil": 86400,"ssl_id": None,"ssl_status": None,"ssl_expires_on": None,"auto_ttl": 1,"service_mode": "0","props": {"proxiable": 1,"cloud_on": 0,"cf_open": 1,"ssl": 0,"expired_ssl": 0,"expiring_ssl": 0,"pending_ssl": 0}},{"rec_id": "17119732","rec_tag": "1faa40f85c78bccb69ee8116e84f3b40","zone_name": "example.com","name": "xnvii.example.com","display_name": "","type": "CNAME","prio": None,"content": "example.com","display_content": "example.com","ttl": "1","ttl_ceil": 86400,"ssl_id": None,"ssl_status": None,"ssl_expires_on": None,"auto_ttl": 1,"service_mode": "1","props": {"proxiable": 1,"cloud_on": 1,"cf_open": 1,"ssl": 0,"expired_ssl": 0,"expiring_ssl": 0,"pending_ssl": 0}},{"rec_id": "16606030","rec_tag": "2012b3a2e49978ef18ee13dd98e6b6f7","zone_name": "example.com","name": "yay.example.com","display_name": "yay","type": "CNAME","prio": None,"content": "domains.tumblr.com","display_content": "domains.tumblr.com","ttl": "1","ttl_ceil": 86400,"ssl_id": None,"ssl_status": None,"ssl_expires_on": None,"auto_ttl": 1,"service_mode": "0","props": {"proxiable": 1,"cloud_on": 0,"cf_open": 1,"ssl": 0,"expired_ssl": 0,"expiring_ssl": 0,"pending_ssl": 0}}]}},"result": "success","msg": None}),
    'zone_check': json.dumps({"response": {"zones": {"example1.com": 1,"example2.com": 2,"example3.com": 3}},"result": "success","msg": None}),
    'zone_ips': json.dumps({"response": {"ips": [{"ip": "[IP of Visitor]","classification": "regular","hits": 44,"latitude": 37.76969909668,"longitude": 122.39330291748,"zone_name": "example.com"},{"ip": "[IP of Visitor]","classification": "regular","hits": 21,"latitude": 37.396099090576,"longitude": 121.96170043945,"zone_name": "example.com"},{"ip": "[IP of Visitor]","classification": "regular","hits": 8,"latitude": 37.76969909668,"longitude": 122.39330291748,"zone_name": "example.com"},{"ip": "[IP of Visitor]","classification": "regular","hits": 4,"latitude": 38,"longitude": 97,"zone_name": "example.com"}]},"result": "success","msg": None}),
    'ip_lkup': json.dumps({"response": {"0.0.0.0": "BAD:0"},"result": "success","msg": None}),
    'zone_settings': json.dumps({"request": {"act": "zone_settings","tkn": "8afbe6dea02407989af4dd4c97bb6e25","a": "zone_settings","z": "example.com","email": "sample@example.com"},"response": {"result": {"objs": [{"userSecuritySetting": "Medium","dev_mode": 1345768790,"ipv46": 3,"ob": 1,"cache_lvl": "agg","outboundLinks": "disabled","async": "0","bic": "1","chl_ttl": "900","exp_ttl": "7200","fpurge_ts": "1345757991","hotlink": "1","img": "171","lazy": "1","minify": "0","outlink": "0","preload": "0","s404": "1","sec_lvl": "med","spdy": "1","ssl": "1","waf_profile": "high"}]}},"result": "success","msg": None}),
    'sec_lvl': json.dumps({u'msg': None, u'result': u'success'}),
    'cache_lvl': json.dumps({u'msg': None, u'result': u'success'}),
    'devmode': json.dumps({"response": {"expires_on": 1336697110,"zone": {"obj": {"zone_id": "42","user_id": "1","zone_name": "example.com","display_name": "example.com","zone_status": "V","zone_mode": "1","host_id": "415","zone_type": "P","host_pubname": "SomeHost","host_website": "http://www.SomeHost.com","vtxt": None,"fqdns": None,"step": "4","zone_status_class": "statusdevmode","zone_status_desc": "<strong>Development mode</strong> active: CloudFlare's accelerated cache is inactive on this site, so changes to cachable content (like images, CSS, or JavaScript) are visible immediately. Press shiftreload if your changes are not immediate. Development mode will automatically toggle off <strong>3 hours</strong> after initial setup.","ns_vanity_map": [ ],"orig_registrar": None,"orig_dnshost": None,"orig_ns_names": None,"props": {"dns_cname": 0,"dns_partner": 1,"dns_anon_partner": 0,"pro": 0,"expired_pro": 0,"pro_sub": 0,"ssl": 0,"expired_ssl": 0,"expired_rs_pro": 0,"reseller_pro": 0,"force_interal": 0,"ssl_needed": 0,"alexa_rank": 0},"confirm_code": {"zone_deactivate": "f91eb75acb516aa95dabf5fa2b7305ec"},"allow": ["analytics","threat_control","cf_apps","dns_editor","cf_settings","page_rules","zone_deactivate","zone_dev_mode0"]}}},"result": "success","msg": None}),
    'fpurge_ts': json.dumps({u'msg': None, u'attributes': {u'cooldown': 20}, u'response': {u'fpurge_ts': 1378840095}, u'result': u'success'}),
    'zone_file_purge': json.dumps({u'msg': None, u'request': {u'act': u'zone_file_purge'}, u'response': {u'url': u'https://site.com/image.jpg', u'vtxt_match': None}, u'result': u'success'}),
    'zone_grab': json.dumps({u'msg': None, u'result': u'success'}),
    'wl': json.dumps({u'msg': None, u'response': {u'result': {u'action': u'WL', u'ip': u'0.0.0.0'}}, u'result': u'success'}),
    'ban': json.dumps({u'msg': None, u'response': {u'result': {u'action': u'BAN', u'ip': u'0.0.0.0'}}, u'result': u'success'}),
    'nul': json.dumps({u'msg': None, u'response': {u'result': {u'action': u'NUL', u'ip': u'0.0.0.0'}}, u'result': u'success'}),
    'ipv46': json.dumps({u'msg': None, u'result': u'success'}),
    'async': json.dumps({u'msg': None, u'result': u'success'}),
    'minify': json.dumps({u'msg': None, u'result': u'success'}),
    'mirage2': json.dumps({u'msg': None, u'result': u'success'}),
    'rec_new': json.dumps({"request": {"act": "rec_new","a": "rec_new","tkn": "8afbe6dea02407989af4dd4c97bb6e25","email": "sample@example.com","type": "A","z": "example.com","name": "test","content": "96.126.126.36","ttl": "1","service_mode": "1"},"response": {"rec": {"obj": {"rec_id": "23734516","rec_tag": "b3db8b8ad50389eb4abae7522b22852f","zone_name": "example.com","name": "test.example.com","display_name": "test","type": "A","prio": None,"content": "96.126.126.36","display_content": "96.126.126.36","ttl": "1","ttl_ceil": 86400,"ssl_id": "12805","ssl_status": "V","ssl_expires_on": None,"auto_ttl": 1,"service_mode": "0","props": {"proxiable": 1,"cloud_on": 0,"cf_open": 1,"ssl": 1,"expired_ssl": 0,"expiring_ssl": 0,"pending_ssl": 0,"vanity_lock": 0}}}},"result": "success","msg": None}),
    'rec_edit': json.dumps({"request": {"act": "rec_edit","a": "rec_edit","tkn": "1296c62233d48a6cf0585b0c1dddc3512e4b2","id": "23734516","email": "sample@example.com","type": "A","z": "example.com","name": "sub","content": "96.126.126.36","ttl": "1","service_mode": "1"},"response": {"rec": {"obj": {"rec_id": "23734516","rec_tag": "b3db8b8ad50389eb4abae7522b22852f","zone_name": "example.com","name": "sub.example.com","display_name": "sub","type": "A","prio": None,"content": "96.126.126.36","display_content": "96.126.126.36","ttl": "1","ttl_ceil": 86400,"ssl_id": "12805","ssl_status": "V","ssl_expires_on": None,"auto_ttl": 1,"service_mode": "1","props": {"proxiable": 1,"cloud_on": 1,"cf_open": 0,"ssl": 1,"expired_ssl": 0,"expiring_ssl": 0,"pending_ssl": 0,"vanity_lock": 0}}}},"result": "success","msg": None}),
    'rec_delete': json.dumps({u'msg': None, u'result': u'success'}),
}


from setuptools import setup, find_packages

long_description = open('README.rst').read()

packages = find_packages(exclude=['tests", "tests.*'])

setup(
    name='pyflare',
    version='1.0.1',
    packages=packages,
    url='https://github.com/jlinn/pyflare',
    license='LICENSE.txt',
    author='Joe Linn',
    author_email='',
    description="An adapter for CloudFlare's client API",
    long_description=long_description,
    install_requires=['requests'],
    classifiers=[
        'Intended Audience :: Developers',
        'Development Status :: 5 - Production/Stable',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP'
    ]
)
